import {
  geoEquirectangular,
  geoPath,
  geoGraticule,
} from 'd3';

//Start drawing map and plot earthquakes:
const projection = geoEquirectangular();
const path = geoPath(projection);
const geoGenerator = geoPath().projection(projection);
const graticule = geoGraticule();

export const map = (
  selection,
  {
    countries,
    tectonic,
    earthquakes,
    colorScale,
    colorValue,
  },
) => {
  //outline of the map
  selection
    .selectAll('path.outline')
    .data([null])
    .join('path')
    .attr('class', 'outline')
    .attr('d', path(graticule.outline()))
    .attr('fill', '#c7d9eb')
    .attr('opacity', 70 / 100)
    //.attr('fill', 'none')
    .attr('stroke', 'black')
    .attr('stroke-width', 1);
  //draw gratucule on map
  selection
    .selectAll('path.graticule')
    .data([null])
    .join('path')
    .attr('class', 'graticule')
    .attr('d', path(graticule()))
    .attr('fill', 'none')
    .attr('stroke', '#BBB')
    .attr('stroke-width', 0.2);
  //draw countries on map
  selection
    .selectAll('path.country')
    .data(countries.features)
    .join('path')
    .attr('d', path)
    .attr('class', 'country');

  //draw tectonic plate boundaries
  selection
    .selectAll('path.tectonic')
    .data(tectonic.features)
    .join('path')
    .attr('d', geoGenerator)
    .attr('class', 'tectonic')
    .attr('fill', 'none')
    .attr('stroke', 'black')
    .attr('stroke-width', 0.7);

  //project earthquakes according to graticules
  for (const d of earthquakes) {
    const [x, y] = projection([d.longitude, d.latitude]);
    d.x = x;
    d.y = y;
  }
  //plot earthquakes on the map
  selection
    .selectAll('circle')
    .data(earthquakes)
    .join('circle')
    .attr('cx', (d) => d.x)
    .attr('cy', (d) => d.y)
    .attr('r', 2)
    .attr('fill', '#101EDA')
    .attr('stroke', 'black')
    .attr('stroke-width', 0.5);
};
