import {
  csvParse,
  select,
  geoPath,
  json,
  scaleOrdinal,
} from 'd3';
import topojson from 'topojson-client';
import { map } from './map';

//data of world map (topoJson)
const worldAtlasURL =
  'https://unpkg.com/visionscarto-world-atlas@0.1.0/world/110m.json';
//data of tectonic plate boundary (geoJson)
const tectonicJSON =
  'https://raw.githubusercontent.com/fraxen/tectonicplates/master/GeoJSON/PB2002_boundaries.json';

export const viz = (container, { state, setState }) => {
  const width = window.innerWidth;
  const height = window.innerHeight;

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height);

  // state.data could be:
  // * undefined
  // * 'LOADING'
  // * An array of objects
  const { countries, tectonic, earthquakes } = state;

  if (
    countries &&
    countries !== 'LOADING' &&
    tectonic &&
    tectonic !== 'LOADING' &&
    earthquakes &&
    earthquakes !== 'LOADING'
  ) {
    svg.call(map, {
      countries,
      tectonic,
      earthquakes,
    });
  }
  //retrieve world map data
  if (countries === undefined) {
    setState((state) => ({
      ...state,
      countries: 'LOADING',
    }));
    fetch(worldAtlasURL)
      .then((response) => response.json())
      .then((topoJSONData) => {
        const countries = topojson.feature(
          topoJSONData,
          'countries',
        );
        setState((state) => ({
          ...state,
          countries,
        }));
      });
    return;
  }
  //retrieve tectonic plate data
  if (tectonic === undefined) {
    setState((state) => ({
      ...state,
      tectonic: 'LOADING',
    }));

    json(tectonicJSON).then((geoJSONData) => {
      const tectonic = geoJSONData;
      setState((state) => ({
        ...state,
        tectonic,
      }));
    });
    //console.log(tectonic);

    return;
  }
  //retrieve earthquakes data
  if (earthquakes === undefined) {
    setState((state) => ({
      ...state,
      earthquakes: 'LOADING',
    }));

    fetch('data.csv')
      .then((response) => response.text())
      .then((csvString) => {
        const earthquakes = csvParse(csvString, (d) => {
          d.latitude = +d.latitude;
          d.longitude = +d.longitude;
          d.mag = +d.mag;
          return d;
        });

        setState((state) => ({
          ...state,
          earthquakes,
        }));
      });
    return;
  }
};
